﻿using ArmoredCar;
using System.Windows.Forms;
using System;

namespace ArmoredCar
{
    public partial class FormMapWithSetArmoredCars : Form
    {
        /// <summary>
        /// Объект от класса карты с набором объектов
        /// </summary>
        private MapWithSetArmoredCarsGeneric<DrawningObjectArmCar, AbstractMap> _mapArmoredCarsCollectionGeneric;
        /// <summary>
        /// Конструктор
        /// </summary>
        public FormMapWithSetArmoredCars()
        {
            InitializeComponent();
        }
        /// <summary>
        /// Выбор карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ComboBoxSelectorMap_SelectedIndexChanged(object sender, EventArgs e)
        {
            AbstractMap map = null;
            switch (comboBoxSelectorMap.Text)
            {
                case "Простая карта":
                    map = new SimpleMap();
                    break;
                case "Карта 1":
                    map = new MyMapLabirinth();
                    break;
            }
            if (map != null)
            {
                _mapArmoredCarsCollectionGeneric = new MapWithSetArmoredCarsGeneric<DrawningObjectArmCar, AbstractMap>(
                    pictureBox.Width, pictureBox.Height, map);
            }
            else
            {
                _mapArmoredCarsCollectionGeneric = null;
            }
        }
        /// <summary>
        /// Добавление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonAddarmoredCar_Click(object sender, EventArgs e)
        {
            if (_mapArmoredCarsCollectionGeneric == null)
            {
                return;
            }
            FormCar form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                DrawningObjectArmCar armoredCar = new(form.SelectedCar);
                if (_mapArmoredCarsCollectionGeneric + armoredCar > -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBox.Image = _mapArmoredCarsCollectionGeneric.ShowSet();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }
        /// <summary>
        /// Удаление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonRemoveArmoredCar_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(maskedTextBoxPosition.Text))
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
            if (_mapArmoredCarsCollectionGeneric - pos != null)
            {
                MessageBox.Show("Объект удален");
                pictureBox.Image = _mapArmoredCarsCollectionGeneric.ShowSet();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }
        /// <summary>
        /// Вывод набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowStorage_Click(object sender, EventArgs e)
        {
            if (_mapArmoredCarsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapArmoredCarsCollectionGeneric.ShowSet();
        }
        /// <summary>
        /// Вывод карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonShowOnMap_Click(object sender, EventArgs e)
        {
            if (_mapArmoredCarsCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapArmoredCarsCollectionGeneric.ShowOnMap();
        }
        /// <summary>
        /// Перемещение
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonMove_Click(object sender, EventArgs e)
        {
            if (_mapArmoredCarsCollectionGeneric == null)
            {
                return;
            }
            
            //получаем имя кнопки
            string name = ((Button)sender)?.Name ?? string.Empty;
            Direction dir = Direction.None;
            switch (name)
            {
                case "buttonUp":
                    dir = Direction.Up;
                    break;
                case "buttonDown":
                    dir = Direction.Down;
                    break;
                case "buttonLeft":
                    dir = Direction.Left;
                    break;
                case "buttonRight":
                    dir = Direction.Right;
                    break;
            }
            pictureBox.Image = _mapArmoredCarsCollectionGeneric.MoveObject(dir);
        }
    }
}